@@ -6,6 +6,7 @@ from ._base import _BaseGeometry
 from .properties import ContextShadeProperties
 
 from honeybee.shade import Shade
+from honeybee.typing import clean_string
 
 from ladybug_geometry.geometry3d.face import Face3D
 
@@ -16,23 +17,25 @@ class ContextShade(_BaseGeometry):
     """A Context Shade object defined by an array of Face3Ds (eg. canopy, trees, etc.).
 
     Args:
-        name: ContextShade name. Must be < 100 characters.
+        identifier: Text string for a unique ContextShade ID. Must be < 100 characters
+            and not contain any spaces or special characters.
         geometry: An array of ladybug_geometry Face3D objects that together
             represent the context shade.
 
     Properties:
-        * name
+        * identifier
         * display_name
         * geometry
         * area
         * min
         * max
+        * user_data
     """
     __slots__ = ('_geometry',)
 
-    def __init__(self, name, geometry):
+    def __init__(self, identifier, geometry):
         """A Context Shade object defined by an array of Face3Ds."""
-        _BaseGeometry.__init__(self, name)  # process the name
+        _BaseGeometry.__init__(self, identifier)  # process the identifier
 
         # process the geometry
         if not isinstance(geometry, tuple):
@@ -57,9 +60,11 @@ class ContextShade(_BaseGeometry):
             'Got {}.'.format(data['type'])
 
         geometry = tuple(Face3D.from_dict(shd_geo) for shd_geo in data['geometry'])
-        shade = cls(data['name'], geometry)
+        shade = cls(data['identifier'], geometry)
         if 'display_name' in data and data['display_name'] is not None:
-            shade._display_name = data['display_name']
+            shade.display_name = data['display_name']
+        if 'user_data' in data and data['user_data'] is not None:
+            shade.user_data = data['user_data']
 
         if data['properties']['type'] == 'ContextShadeProperties':
             shade.properties._load_extension_attr_from_dict(data['properties'])
@@ -94,19 +99,20 @@ class ContextShade(_BaseGeometry):
         return self._calculate_max(self._geometry)
 
     def add_prefix(self, prefix):
-        """Change the name of this object by inserting a prefix.
+        """Change the identifier of this object by inserting a prefix.
 
         This is particularly useful in workflows where you duplicate and edit
         a starting object and then want to combine it with the original object
         into one Model (like making a model of repeated shades) since all objects
-        within a Model must have unique names.
+        within a Model must have unique identifiers.
 
         Args:
-            prefix: Text that will be inserted at the start of this object's name
-                and display_name. It is recommended that this name be short to
-                avoid maxing out the 100 allowable characters for honeybee names.
+            prefix: Text that will be inserted at the start of this object's identifier
+                and display_name. It is recommended that this prefix be short to
+                avoid maxing out the 100 allowable characters for dragonfly identifiers.
         """
-        self.name = '{}_{}'.format(prefix, self.display_name)
+        self._identifier = clean_string('{}_{}'.format(prefix, self.identifier))
+        self.display_name = '{}_{}'.format(prefix, self.display_name)
         self.properties.add_prefix(prefix)
 
     def move(self, moving_vec):
@@ -154,7 +160,8 @@ class ContextShade(_BaseGeometry):
         shades = []
         for i, shd_geo in enumerate(self._geometry):
             # create the shade object
-            shade = Shade('{}_{}'.format(self.display_name, i), shd_geo)
+            shade = Shade('{}_{}'.format(self.identifier, i), shd_geo)
+            shade.display_name = '{}_{}'.format(self.display_name, i)
             # transfer any extension properties assigned to the Shade
             shade._properties = self.properties.to_honeybee(shade)
             shades.append(shade)
@@ -166,24 +173,27 @@ class ContextShade(_BaseGeometry):
         Args:
             abridged: Boolean to note whether the extension properties of the
                 object (ie. materials, transmittance schedule) should be included in
-                detail (False) or just referenced by name (True). Default: False.
+                detail (False) or just referenced by identifier (True). Default: False.
             included_prop: List of properties to filter keys that must be included in
                 output dictionary. For example ['energy'] will include 'energy' key if
                 available in properties to_dict. By default all the keys will be
                 included. To exclude all the keys from extensions use an empty list.
         """
         base = {'type': 'ContextShade'}
-        base['name'] = self.name
+        base['identifier'] = self.identifier
         base['display_name'] = self.display_name
         base['properties'] = self.properties.to_dict(abridged, included_prop)
         enforce_upper_left = True if 'energy' in base['properties'] else False
         base['geometry'] = [shd_geo.to_dict(False, enforce_upper_left)
                             for shd_geo in self._geometry]
+        if self.user_data is not None:
+            base['user_data'] = self.user_data
         return base
 
     def __copy__(self):
-        new_shd = ContextShade(self.name, self._geometry)
+        new_shd = ContextShade(self.identifier, self._geometry)
         new_shd._display_name = self.display_name
+        new_shd._user_data = None if self.user_data is None else self.user_data.copy()
         new_shd._properties._duplicate_extension_attr(self._properties)
         return new_shd
 
