@@ -9,7 +9,7 @@ from dragonfly.windowparameter import _WindowParameterBase, _AsymmetricBase
 import dragonfly.shadingparameter as shdpar
 from dragonfly.shadingparameter import _ShadingParameterBase
 
-from honeybee.typing import float_positive
+from honeybee.typing import float_positive, clean_string
 import honeybee.boundarycondition as hbc
 from honeybee.boundarycondition import boundary_conditions as bcs
 from honeybee.boundarycondition import _BoundaryCondition, Outdoors, Surface
@@ -31,9 +31,10 @@ class Room2D(_BaseGeometry):
     """A volume defined by an extruded floor plate, representing a single room or space.
 
     Args:
-        name: Room2D name. Must be < 100 characters.
+        identifier: Text string for a unique Room2D ID. Must be < 100 characters and
+            not contain any spaces or special characters.
         floor_geometry: A single horizontal Face3D object representing the
-            floor plate of the Room. Note that this Face3D must be horiztional
+            floor plate of the Room. Note that this Face3D must be horizontal
             to be valid.
         floor_to_ceiling_height: A number for the height above the floor where the
             ceiling begins. Typical values range from 3 to 5 meters.
@@ -59,7 +60,7 @@ class Room2D(_BaseGeometry):
             floor plane. Default is 0, which will not perform any check.
 
     Properties:
-        * name
+        * identifier
         * display_name
         * floor_geometry
         * floor_to_ceiling_height
@@ -82,17 +83,18 @@ class Room2D(_BaseGeometry):
         * exterior_aperture_area
         * min
         * max
+        * user_data
     """
     __slots__ = ('_floor_geometry', '_segment_count', '_floor_to_ceiling_height',
                  '_boundary_conditions', '_window_parameters', '_shading_parameters',
                  '_is_ground_contact', '_is_top_exposed', '_parent')
 
-    def __init__(self, name, floor_geometry, floor_to_ceiling_height,
+    def __init__(self, identifier, floor_geometry, floor_to_ceiling_height,
                  boundary_conditions=None, window_parameters=None,
                  shading_parameters=None, is_ground_contact=False, is_top_exposed=False,
                  tolerance=0):
         """A volume defined by an extruded floor plate, representing a single room."""
-        _BaseGeometry.__init__(self, name)  # process the name
+        _BaseGeometry.__init__(self, identifier)  # process the identifier
 
         # process the floor_geometry
         assert isinstance(floor_geometry, Face3D), \
@@ -109,7 +111,7 @@ class Room2D(_BaseGeometry):
         if tolerance != 0:
             z_vals = tuple(pt.z for pt in self._floor_geometry.vertices)
             assert max(z_vals) - min(z_vals) <= tolerance, 'Not all of Room2D ' \
-                '"{}" vertices lie within the same horizontal plane.'.format(name)
+                '"{}" vertices lie within the same horizontal plane.'.format(identifier)
 
         # process segment count and floor-to-ceiling height
         self._segment_count = len(self.floor_segments)
@@ -120,7 +122,7 @@ class Room2D(_BaseGeometry):
             bc = bcs.outdoors if self.ceiling_height > 0 else bcs.ground
             self._boundary_conditions = [bc for i in range(len(self))]
         else:
-            value = self._check_wall_assinged_object(
+            value = self._check_wall_assigned_object(
                 boundary_conditions, 'boundary_conditions')
             for val in value:
                 assert isinstance(val, _BoundaryCondition), \
@@ -131,9 +133,8 @@ class Room2D(_BaseGeometry):
         self.window_parameters = window_parameters
         self.shading_parameters = shading_parameters
 
-        # ensure all wall-asigned objects align with the geometry if it has been flipped
+        # ensure all wall-assigned objects align with the geometry if it has been flipped
         if floor_geometry.normal.z < 0:
-
             new_bcs, new_win_pars, new_shd_pars = Room2D._flip_wall_assigned_objects(
                 floor_geometry, self._boundary_conditions, self._window_parameters,
                 self._shading_parameters)
@@ -181,7 +182,7 @@ class Room2D(_BaseGeometry):
                     bc_class = getattr(hbc, bc_dict['type'])
                 except AttributeError:
                     raise ValueError(
-                        'Boundary condition "{}" is not supported in this honyebee '
+                        'Boundary condition "{}" is not supported in this honeybee '
                         'installation.'.format(bc_dict['type']))
                 b_conditions.append(bc_class.from_dict(bc_dict))
         else:
@@ -196,7 +197,7 @@ class Room2D(_BaseGeometry):
                         glz_class = getattr(glzpar, glz_dict['type'])
                     except AttributeError:
                         raise ValueError(
-                            'Window parameter "{}" is not supported in this honyebee '
+                            'Window parameter "{}" is not supported in this honeybee '
                             'installation.'.format(glz_dict['type']))
                     glz_pars.append(glz_class.from_dict(glz_dict))
                 else:
@@ -213,7 +214,7 @@ class Room2D(_BaseGeometry):
                         shd_class = getattr(shdpar, shd_dict['type'])
                     except AttributeError:
                         raise ValueError(
-                            'Shading parameter "{}" is not supported in this honyebee '
+                            'Shading parameter "{}" is not supported in this honeybee '
                             'installation.'.format(shd_dict['type']))
                     shd_pars.append(shd_class.from_dict(shd_dict))
                 else:
@@ -225,17 +226,19 @@ class Room2D(_BaseGeometry):
         grnd = data['is_ground_contact'] if 'is_ground_contact' in data else False
         top = data['is_top_exposed'] if 'is_top_exposed' in data else False
 
-        room = Room2D(data['name'], floor_geometry, data['floor_to_ceiling_height'],
+        room = Room2D(data['identifier'], floor_geometry, data['floor_to_ceiling_height'],
                       b_conditions, glz_pars, shd_pars, grnd, top, tolerance)
         if 'display_name' in data and data['display_name'] is not None:
             room._display_name = data['display_name']
+        if 'user_data' in data and data['user_data'] is not None:
+            room.user_data = data['user_data']
 
         if data['properties']['type'] == 'Room2DProperties':
             room.properties._load_extension_attr_from_dict(data['properties'])
         return room
 
     @classmethod
-    def from_polygon(cls, name, polygon, floor_height, floor_to_ceiling_height,
+    def from_polygon(cls, identifier, polygon, floor_height, floor_to_ceiling_height,
                      boundary_conditions=None, window_parameters=None,
                      shading_parameters=None, is_ground_contact=False,
                      is_top_exposed=False):
@@ -245,7 +248,8 @@ class Room2D(_BaseGeometry):
         (like a courtyard) since polygons cannot have holes within them.
 
         Args:
-            name: Room2D name. Must be < 100 characters.
+            identifier: Text string for a unique Room2D ID. Must be < 100 characters
+                and not contain any spaces or special characters.
             polygon: A single Polygon2D object representing the floor plate of the Room.
             floor_height: A float value to place the polygon within 3D space.
             floor_to_ceiling_height: A number for the height above the floor where the
@@ -290,12 +294,12 @@ class Room2D(_BaseGeometry):
         vert3d = tuple(base_plane.xy_to_xyz(_v) for _v in polygon.vertices)
         floor_geometry = Face3D(vert3d, base_plane, enforce_right_hand=False)
 
-        return cls(name, floor_geometry, floor_to_ceiling_height, boundary_conditions,
-                   window_parameters, shading_parameters, is_ground_contact,
-                   is_top_exposed)
+        return cls(identifier, floor_geometry, floor_to_ceiling_height,
+                   boundary_conditions, window_parameters, shading_parameters,
+                   is_ground_contact, is_top_exposed)
 
     @classmethod
-    def from_vertices(cls, name, vertices, floor_height, floor_to_ceiling_height,
+    def from_vertices(cls, identifier, vertices, floor_height, floor_to_ceiling_height,
                       boundary_conditions=None, window_parameters=None,
                       shading_parameters=None, is_ground_contact=False,
                       is_top_exposed=False):
@@ -306,7 +310,8 @@ class Room2D(_BaseGeometry):
         vertices cannot be derived from a single list of vertices.
 
         Args:
-            name: Room2D name. Must be < 100 characters.
+            identifier: Text string for a unique Room2D ID. Must be < 100 characters
+                and not contain any spaces or special characters.
             vertices: A flattened list of 2 or more vertices as (x, y) that trace
                 the outline of the floor plate.
             floor_height: A float value to place the polygon within 3D space.
@@ -331,7 +336,7 @@ class Room2D(_BaseGeometry):
         """
         polygon = Polygon2D(tuple(Point2D(*v) for v in vertices))
         return cls.from_polygon(
-            name, polygon, floor_height, floor_to_ceiling_height,
+            identifier, polygon, floor_height, floor_to_ceiling_height,
             boundary_conditions, window_parameters, shading_parameters,
             is_ground_contact, is_top_exposed)
 
@@ -356,7 +361,7 @@ class Room2D(_BaseGeometry):
 
     @boundary_conditions.setter
     def boundary_conditions(self, value):
-        value = self._check_wall_assinged_object(value, 'boundary conditions')
+        value = self._check_wall_assigned_object(value, 'boundary conditions')
         for val, glz in zip(value, self._window_parameters):
             assert val in bcs, 'Expected BoundaryCondition. Got {}'.format(type(value))
             if glz is not None:
@@ -373,7 +378,7 @@ class Room2D(_BaseGeometry):
     @window_parameters.setter
     def window_parameters(self, value):
         if value is not None:
-            value = self._check_wall_assinged_object(value, 'window_parameters')
+            value = self._check_wall_assigned_object(value, 'window_parameters')
             for val, bc in zip(value, self._boundary_conditions):
                 if val is not None:
                     assert isinstance(val, _WindowParameterBase), \
@@ -393,7 +398,7 @@ class Room2D(_BaseGeometry):
     @shading_parameters.setter
     def shading_parameters(self, value):
         if value is not None:
-            value = self._check_wall_assinged_object(value, 'shading_parameters')
+            value = self._check_wall_assigned_object(value, 'shading_parameters')
             for val in value:
                 if val is not None:
                     assert isinstance(val, _ShadingParameterBase), \
@@ -554,27 +559,28 @@ class Room2D(_BaseGeometry):
         self._shading_parameters = shd_ps
 
     def add_prefix(self, prefix):
-        """Change the name of this object and all child segments by inserting a prefix.
+        """Change the identifier of this object by inserting a prefix.
 
         This is particularly useful in workflows where you duplicate and edit
         a starting object and then want to combine it with the original object
         into one Model (like making a model of repeated rooms) since all objects
-        within a Model must have unique names.
+        within a Model must have unique identifiers.
 
         Args:
             prefix: Text that will be inserted at the start of this object's
-                (and child segments') name and display_name. It is recommended
-                that this name be short to avoid maxing out the 100 allowable
-                characters for honeybee names.
+                (and child segments') identifier and display_name. It is recommended
+                that this prefix be short to avoid maxing out the 100 allowable
+                characters for dragonfly identifiers.
         """
-        self.name = '{}_{}'.format(prefix, self.display_name)
+        self._identifier = clean_string('{}_{}'.format(prefix, self.identifier))
+        self.display_name = '{}_{}'.format(prefix, self.display_name)
         self.properties.add_prefix(prefix)
         for i, bc in enumerate(self._boundary_conditions):
             if isinstance(bc, Surface):
-                new_face_name = '{}_{}'.format(prefix, bc.boundary_condition_objects[0])
-                new_room_name = '{}_{}'.format(prefix, bc.boundary_condition_objects[1])
+                new_face_id = '{}_{}'.format(prefix, bc.boundary_condition_objects[0])
+                new_room_id = '{}_{}'.format(prefix, bc.boundary_condition_objects[1])
                 self._boundary_conditions[i] = \
-                    Surface((new_face_name, new_room_name))
+                    Surface((new_face_id, new_room_id))
 
     def generate_grid(self, x_dim, y_dim=None, offset=1.0):
         """Get a gridded Mesh3D object offset from the floor of this room.
@@ -591,10 +597,13 @@ class Room2D(_BaseGeometry):
                 Default is 1.0, which will not offset the grid to be 1 unit above
                 the floor.
         """
-        return self.floor_geometry.get_mesh_grid(x_dim, y_dim, offset, False)
+        return self.floor_geometry.mesh_grid(x_dim, y_dim, offset, False)
 
     def set_adjacency(self, other_room_2d, self_seg_index, other_seg_index):
-        """Set this Room2D to be adjacent to another and vice versa.
+        """Set a segment of this Room2D to be adjacent to another and vice versa.
+
+        Note that, adjacent segments must possess matching WindowParameters in
+        order to be valid.
 
         Args:
             other_room_2d: Another Room2D object to be set adjacent to this one.
@@ -606,27 +615,19 @@ class Room2D(_BaseGeometry):
         assert isinstance(other_room_2d, Room2D), \
             'Expected dragonfly Room2D. Got {}.'.format(type(other_room_2d))
         # set the boundary conditions of the segments
-        names_1 = ('{}..Face{}'.format(self.name, self_seg_index + 1),
-                   self.name)
-        names_2 = ('{}..Face{}'.format(other_room_2d.name, other_seg_index + 1),
-                   other_room_2d.name)
-        self._boundary_conditions[self_seg_index] = Surface(names_2)
-        other_room_2d._boundary_conditions[other_seg_index] = Surface(names_1)
-        # check that the window parameters match
+        ids_1 = ('{}..Face{}'.format(self.identifier, self_seg_index + 1),
+                 self.identifier)
+        ids_2 = ('{}..Face{}'.format(other_room_2d.identifier, other_seg_index + 1),
+                 other_room_2d.identifier)
+        self._boundary_conditions[self_seg_index] = Surface(ids_2)
+        other_room_2d._boundary_conditions[other_seg_index] = Surface(ids_1)
+        # check that the window parameters match between segments
         if self._window_parameters[self_seg_index] is not None or \
                 other_room_2d._window_parameters[other_seg_index] is not None:
             assert self._window_parameters[self_seg_index] == \
                 other_room_2d._window_parameters[other_seg_index], \
                 'Window parameters do not match between adjacent Room2Ds "{}" and ' \
-                '"{}".'.format(self.name, other_room_2d.name)
-            assert self.floor_to_ceiling_height == \
-                other_room_2d.floor_to_ceiling_height, 'floor_to_ceiling_height does '\
-                'not match between Room2Ds "{}" and "{}" with interior windows.'.format(
-                    self.name, other_room_2d.name)
-            assert self.floor_height == \
-                other_room_2d.floor_height, 'floor_height does not match between '\
-                'Room2Ds "{}" and "{}" with interior windows.'.format(
-                    self.name, other_room_2d.name)
+                '"{}".'.format(self.identifier, other_room_2d.identifier)
 
     def set_boundary_condition(self, self_seg_index, boundary_condition):
         """Set a single segment of this Room2D to have a certain boundary condition.
@@ -704,7 +705,7 @@ class Room2D(_BaseGeometry):
                 self._shading_parameters[i] = shd_par.scale(factor)
 
     def check_horizontal(self, tolerance=0.01, raise_exception=True):
-        """Check whether the Room2D's floor geometry is horiztonal within a tolerance.
+        """Check whether the Room2D's floor geometry is horizontal within a tolerance.
 
         Args:
             tolerance: The maximum difference between z values at which
@@ -737,10 +738,11 @@ class Room2D(_BaseGeometry):
         """
         new_geo = self.floor_geometry.remove_colinear_vertices(tolerance)
         rebuilt_room = Room2D(
-                self.name, new_geo, self.floor_to_ceiling_height,
+                self.identifier, new_geo, self.floor_to_ceiling_height,
                 is_ground_contact=self.is_ground_contact,
                 is_top_exposed=self.is_top_exposed)
         rebuilt_room._display_name = self.display_name
+        rebuilt_room._user_data = self._user_data
         rebuilt_room._parent = self._parent
         rebuilt_room._properties._duplicate_extension_attr(self._properties)
         return rebuilt_room
@@ -758,15 +760,31 @@ class Room2D(_BaseGeometry):
                 floor_to_ceiling_height at which adjacent Faces will be split.
                 This is also used in the generation of Windows. Default: 0.01,
                 suitable for objects in meters.
+        
+        Returns:
+            A tuple with the two items below.
+
+            * hb_room -- A honeybee-core Room representing the dragonfly Room2D
+
+            * adjacencies -- A list of tuples that record any adjacencies that
+                should be set on the level of the Story to which the Room2D belongs.
+                Each tuple will have a honeybee Face as the first item and a
+                tuple of Surface.boundary_condition_objects as the second item.
         """
         # create the honeybee Room
         room_polyface = Polyface3D.from_offset_face(
             self._floor_geometry, self.floor_to_ceiling_height)
-        hb_room = Room.from_polyface3d(self.display_name, room_polyface)
+        hb_room = Room.from_polyface3d(self.identifier, room_polyface)
 
-        # assign boundary conditions, window and shading to walls
+        # assign BCs and record any Surface conditions to be set on the story level
+        adjacencies = []
         for i, bc in enumerate(self._boundary_conditions):
-            hb_room[i + 1]._boundary_condition = bc
+            if not isinstance(bc, Surface):
+                hb_room[i + 1]._boundary_condition = bc
+            else:
+                adjacencies.append((hb_room[i + 1], bc.boundary_condition_objects))
+
+        # assign windows and shading to walls
         for i, glz_par in enumerate(self._window_parameters):
             if glz_par is not None:
                 glz_par.add_window_to_face(hb_room[i + 1], tolerance)
@@ -777,11 +795,21 @@ class Room2D(_BaseGeometry):
         # ensure matching adjacent Faces across the Story if tolerance is input
         if self._parent is not None:
             new_faces = self._split_walls_along_height(hb_room, tolerance)
-            if len(new_faces) != len(hb_room):  # rebuild the room with split surfaces
-                hb_room = Room(self.name, new_faces, tolerance, 0.1)
+            if len(new_faces) != len(hb_room):
+                # rebuild the room with split surfaces
+                hb_room = Room(self.identifier, new_faces, tolerance, 0.1)
+                # update adjacencies with the new split face
+                for i, adj in enumerate(adjacencies):
+                    face_id = adj[0].identifier
+                    for face in hb_room.faces:
+                        if face.identifier == face_id:
+                            adjacencies[i] = (face, adj[1])
+                            break
 
-        # set the multiplier
+        # set the multiplier, display_name, and user_data
         hb_room.multiplier = multiplier
+        hb_room._display_name = self._display_name
+        hb_room._user_data = self._user_data
 
         # assign boundary conditions for the roof and floor
         try:
@@ -797,22 +825,22 @@ class Room2D(_BaseGeometry):
         # transfer any extension properties assigned to the Room2D
         hb_room._properties = self.properties.to_honeybee(hb_room)
 
-        return hb_room
+        return hb_room, adjacencies
 
     def to_dict(self, abridged=False, included_prop=None):
         """Return Room2D as a dictionary.
 
         Args:
             abridged: Boolean to note whether the extension properties of the
-                object (ie. program_type, construciton_set) should be included in detail
-                (False) or just referenced by name (True). Default: False.
+                object (ie. program_type, construction_set) should be included in detail
+                (False) or just referenced by identifier (True). Default: False.
             included_prop: List of properties to filter keys that must be included in
                 output dictionary. For example ['energy'] will include 'energy' key if
                 available in properties to_dict. By default all the keys will be
                 included. To exclude all the keys from extensions use an empty list.
         """
         base = {'type': 'Room2D'}
-        base['name'] = self.name
+        base['identifier'] = self.identifier
         base['display_name'] = self.display_name
         base['properties'] = self.properties.to_dict(abridged, included_prop)
         base['floor_boundary'] = [(pt.x, pt.y) for pt in self._floor_geometry.boundary]
@@ -844,6 +872,9 @@ class Room2D(_BaseGeometry):
                 val = shd.to_dict() if shd is not None else None
                 base['shading_parameters'].append(val)
 
+        if self.user_data is not None:
+            base['user_data'] = self.user_data
+
         return base
 
     @staticmethod
@@ -899,7 +930,7 @@ class Room2D(_BaseGeometry):
         runing this method.
 
         Args:
-            room_2ds: A list of Room2Ds for which adjacencent segments will be
+            room_2ds: A list of Room2Ds for which adjacent segments will be
                 intersected.
             tolerance: The minimum difference between the coordinate values of two
                 faces at which they can be considered adjacent. Default: 0.01,
@@ -955,16 +986,18 @@ class Room2D(_BaseGeometry):
                 new_geo = Face3D(face_loops[0], room_2ds[i].floor_geometry.plane,
                                  face_loops[1])
             rebuilt_room = Room2D(
-                room_2ds[i].name, new_geo, room_2ds[i].floor_to_ceiling_height,
+                room_2ds[i].identifier, new_geo, room_2ds[i].floor_to_ceiling_height,
                 is_ground_contact=room_2ds[i].is_ground_contact,
                 is_top_exposed=room_2ds[i].is_top_exposed)
             rebuilt_room._display_name = room_2ds[i].display_name
+            rebuilt_room._user_data = None if room_2ds[i].user_data is None else \
+                room_2ds[i].user_data.copy()
             rebuilt_room._parent = room_2ds[i]._parent
             rebuilt_room._properties._duplicate_extension_attr(room_2ds[i]._properties)
             intersected_rooms.append(rebuilt_room)
         return tuple(intersected_rooms)
 
-    def _check_wall_assinged_object(self, value, obj_name=''):
+    def _check_wall_assigned_object(self, value, obj_name=''):
         """Check an input that gets assigned to all of the walls of the Room."""
         try:
             value = list(value) if not isinstance(value, list) else value
@@ -1010,7 +1043,7 @@ class Room2D(_BaseGeometry):
         return new_bcs, new_win_pars, new_shd_pars
 
     def _split_walls_along_height(self, hb_room, tolerance):
-        """Split adjacent walls to ensure matching surface areas in to_honyebee workflow.
+        """Split adjacent walls to ensure matching surface areas in to_honeybee workflow.
 
         Args:
             hb_room: A non-split Honeybee Room representation of this Room2D.
@@ -1023,7 +1056,7 @@ class Room2D(_BaseGeometry):
             if not isinstance(bc, Surface):
                 new_faces.append(face)
             else:
-                adj_rm = self._parent.room_by_name(bc.boundary_condition_objects[-1])
+                adj_rm = self._parent.room_by_identifier(bc.boundary_condition_objects[-1])
                 flr_diff = adj_rm.floor_height - self.floor_height
                 ciel_diff = self.ceiling_height - adj_rm.ceiling_height
                 if flr_diff <= tolerance and ciel_diff <= tolerance:
@@ -1041,8 +1074,9 @@ class Room2D(_BaseGeometry):
                     above = Face3D.from_extrusion(lseg.move(vec2), Vector3D(0, 0, ciel_diff))
                     mid_face = face.duplicate()
                     mid_face._geometry = mid
-                    below_face = Face('{}_Below'.format(face.name), below)
-                    above_face = Face('{}_Above'.format(face.name), above)
+                    self._reassign_split_windows(mid_face, i, tolerance)
+                    below_face = Face('{}_Below'.format(face.identifier), below)
+                    above_face = Face('{}_Above'.format(face.identifier), above)
                     try:
                         below_face.boundary_condition = bcs.adiabatic
                         above_face.boundary_condition = bcs.adiabatic
@@ -1059,7 +1093,8 @@ class Room2D(_BaseGeometry):
                     mid = Face3D.from_extrusion(lseg.move(vec1), Vector3D(0, 0, mid_dist))
                     mid_face = face.duplicate()
                     mid_face._geometry = mid
-                    below_face = Face('{}_Below'.format(face.name), below)
+                    self._reassign_split_windows(mid_face, i, tolerance)
+                    below_face = Face('{}_Below'.format(face.identifier), below)
                     try:
                         below_face.boundary_condition = bcs.adiabatic
                     except AttributeError:
@@ -1075,7 +1110,8 @@ class Room2D(_BaseGeometry):
                     above = Face3D.from_extrusion(lseg.move(vec1), Vector3D(0, 0, ciel_diff))
                     mid_face = face.duplicate()
                     mid_face._geometry = mid
-                    above_face = Face('{}_Above'.format(face.name), above)
+                    self._reassign_split_windows(mid_face, i, tolerance)
+                    above_face = Face('{}_Above'.format(face.identifier), above)
                     try:
                         above_face.boundary_condition = bcs.adiabatic
                     except AttributeError:
@@ -1084,10 +1120,25 @@ class Room2D(_BaseGeometry):
         new_faces.append(hb_room[-1])
         return new_faces
 
+    def _reassign_split_windows(self, face, i, tolerance):
+        """Re-assign WindowParamters to any base surface that has been split.
+
+        Args:
+            face: Honeybee Face to which windows will be re-assigned.
+            i: The index of the window_parameters that correspond to the face
+            tolerance: The tolerance, which will be used to re-assign windows.
+        """
+        glz_par = self._window_parameters[i]
+        if glz_par is not None:
+            face.remove_apertures()
+            glz_par.add_window_to_face(face, tolerance)
+
     def __copy__(self):
-        new_r = Room2D(self.name, self._floor_geometry, self.floor_to_ceiling_height,
+        new_r = Room2D(self.identifier, self._floor_geometry,
+                       self.floor_to_ceiling_height,
                        self._boundary_conditions[:])  # copy boundary condition list
         new_r._display_name = self.display_name
+        new_r._user_data = None if self.user_data is None else self.user_data.copy()
         new_r._parent = self._parent
         new_r._window_parameters = self._window_parameters[:]  # copy window list
         new_r._shading_parameters = self._shading_parameters[:]  # copy shading list
