@@ -22,17 +22,17 @@ def test_story_init():
     pts_2 = (Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(20, 10, 3), Point3D(20, 0, 3))
     pts_3 = (Point3D(0, 10, 3), Point3D(0, 20, 3), Point3D(10, 20, 3), Point3D(10, 10, 3))
     pts_4 = (Point3D(10, 10, 3), Point3D(10, 20, 3), Point3D(20, 20, 3), Point3D(20, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    room2d_3 = Room2D('Office 3', Face3D(pts_3), 3)
-    room2d_4 = Room2D('Office 4', Face3D(pts_4), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2, room2d_3, room2d_4])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    room2d_3 = Room2D('Office3', Face3D(pts_3), 3)
+    room2d_4 = Room2D('Office4', Face3D(pts_4), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2, room2d_3, room2d_4])
     story.solve_room_2d_adjacency(0.01)
     story.set_outdoor_window_parameters(SimpleWindowRatio(0.4))
 
     str(story)  # test the string representation
-    assert story.name == 'OfficeFloor'
-    assert story.display_name == 'Office Floor'
+    assert story.identifier == 'OfficeFloor'
+    assert story.display_name == 'OfficeFloor'
     assert len(story.room_2ds) == 4
     for room in story.room_2ds:
         assert isinstance(room, Room2D)
@@ -54,11 +54,11 @@ def test_story_floor_geometry():
     pts_2 = (Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(20, 10, 3), Point3D(20, 0, 3))
     pts_3 = (Point3D(0, 10, 3), Point3D(0, 20, 3), Point3D(10, 20, 3), Point3D(10, 10, 3))
     pts_4 = (Point3D(10, 10, 3), Point3D(10, 20, 3), Point3D(20, 20, 3), Point3D(20, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    room2d_3 = Room2D('Office 3', Face3D(pts_3), 3)
-    room2d_4 = Room2D('Office 4', Face3D(pts_4), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2, room2d_3, room2d_4])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    room2d_3 = Room2D('Office3', Face3D(pts_3), 3)
+    room2d_4 = Room2D('Office4', Face3D(pts_4), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2, room2d_3, room2d_4])
 
     floor_geo = story.floor_geometry(0.01)
     outline_segs = story.outline_segments(0.01)
@@ -75,24 +75,24 @@ def test_story_add_rooms():
     pts_2 = (Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(20, 10, 3), Point3D(20, 0, 3))
     pts_3 = (Point3D(0, 10, 3), Point3D(0, 20, 3), Point3D(10, 20, 3), Point3D(10, 10, 3))
     pts_4 = (Point3D(10, 10, 3), Point3D(10, 20, 3), Point3D(20, 20, 3), Point3D(20, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    room2d_3 = Room2D('Office 3', Face3D(pts_3), 3)
-    room2d_4 = Room2D('Office 4', Face3D(pts_4), 3)
-    story = Story('Office Floor', [room2d_1])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    room2d_3 = Room2D('Office3', Face3D(pts_3), 3)
+    room2d_4 = Room2D('Office4', Face3D(pts_4), 3)
+    story = Story('OfficeFloor', [room2d_1])
 
     assert story.floor_area == 100
-    assert isinstance(story.room_by_name('Office1'), Room2D) 
+    assert isinstance(story.room_by_identifier('Office1'), Room2D) 
     with pytest.raises(ValueError):
-        story.room_by_name('Office2')
+        story.room_by_identifier('Office2')
     story.add_room_2d(room2d_2)
     assert story.floor_area == 200
-    assert isinstance(story.room_by_name('Office2'), Room2D)
+    assert isinstance(story.room_by_identifier('Office2'), Room2D)
     with pytest.raises(ValueError):
-        story.room_by_name('Office3')
+        story.room_by_identifier('Office3')
     story.add_room_2ds([room2d_3, room2d_4])
     assert story.floor_area == 400
-    assert isinstance(story.room_by_name('Office3'), Room2D)
+    assert isinstance(story.room_by_identifier('Office3'), Room2D)
 
 
 def test_room2d_set_outdoor_window_shading_parameters():
@@ -101,11 +101,11 @@ def test_room2d_set_outdoor_window_shading_parameters():
     pts_2 = (Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(20, 10, 3), Point3D(20, 0, 3))
     pts_3 = (Point3D(0, 10, 3), Point3D(0, 20, 3), Point3D(10, 20, 3), Point3D(10, 10, 3))
     pts_4 = (Point3D(10, 10, 3), Point3D(10, 20, 3), Point3D(20, 20, 3), Point3D(20, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    room2d_3 = Room2D('Office 3', Face3D(pts_3), 3)
-    room2d_4 = Room2D('Office 4', Face3D(pts_4), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2, room2d_3, room2d_4])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    room2d_3 = Room2D('Office3', Face3D(pts_3), 3)
+    room2d_4 = Room2D('Office4', Face3D(pts_4), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2, room2d_3, room2d_4])
     story.solve_room_2d_adjacency(0.01)
 
     ashrae_base = SimpleWindowRatio(0.4)
@@ -126,9 +126,9 @@ def test_generate_grid():
     """Test the generate_grid method."""
     pts_1 = (Point3D(0, 0, 3), Point3D(0, 10, 3), Point3D(10, 10, 3), Point3D(10, 0, 3))
     pts_2 = (Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(20, 10, 3), Point3D(20, 0, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
 
     mesh_grid = story.generate_grid(1)
     assert len(mesh_grid) == 2
@@ -142,9 +142,9 @@ def test_move():
     """Test the Story move method."""
     pts_1 = (Point3D(0, 0, 3), Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(0, 10, 3))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
 
     vec_1 = Vector3D(2, 2, 2)
     new_s = story.duplicate()
@@ -165,9 +165,9 @@ def test_scale():
     """Test the Room2D scale method."""
     pts_1 = (Point3D(0, 0, 3), Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(0, 10, 3))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
 
     new_s = story.duplicate()
     new_s.scale(2)
@@ -187,8 +187,8 @@ def test_rotate_xy():
     """Test the Story rotate_xy method."""
     pts = (Point3D(1, 1, 2), Point3D(2, 1, 2), Point3D(2, 2, 2), Point3D(1, 2, 2))
     plane = Plane(Vector3D(0, 0, 1), Point3D(0, 0, 2))
-    room = Room2D('Square Shoebox', Face3D(pts, plane), 3)
-    story = Story('Office Floor', [room])
+    room = Room2D('SquareShoebox', Face3D(pts, plane), 3)
+    story = Story('OfficeFloor', [room])
     origin_1 = Point3D(1, 1, 0)
 
     test_1 = story.duplicate()
@@ -214,8 +214,8 @@ def test_reflect():
     """Test the Story reflect method."""
     pts = (Point3D(1, 1, 2), Point3D(2, 1, 2), Point3D(2, 2, 2), Point3D(1, 2, 2))
     plane = Plane(Vector3D(0, 0, 1), Point3D(0, 0, 2))
-    room = Room2D('Square Shoebox', Face3D(pts, plane), 3)
-    story = Story('Office Floor', [room])
+    room = Room2D('SquareShoebox', Face3D(pts, plane), 3)
+    story = Story('OfficeFloor', [room])
 
     origin_1 = Point3D(1, 0, 2)
     normal_1 = Vector3D(1, 0, 0)
@@ -235,73 +235,79 @@ def test_to_honeybee():
     """Test the to_honeybee method."""
     pts_1 = (Point3D(0, 0, 3), Point3D(10, 0, 3), Point3D(10, 10, 3), Point3D(0, 10, 3))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 3)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 3)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
     story.solve_room_2d_adjacency(0.01)
     story.set_outdoor_window_parameters(SimpleWindowRatio(0.4))
 
-    hb_model = story.to_honeybee(0.01)
-    assert isinstance(hb_model, Model)
-    assert len(hb_model.rooms) == 2
-    assert len(hb_model.rooms[0]) == 6
-    assert hb_model.rooms[0].volume == 300
-    assert hb_model.rooms[0].floor_area == 100
-    assert hb_model.rooms[0].exterior_wall_area == 90
-    assert hb_model.rooms[0].exterior_aperture_area == pytest.approx(90 * 0.4, rel=1e-3)
-    assert hb_model.rooms[0].average_floor_height == 3
-    assert hb_model.rooms[0].check_solid(0.01, 1)
+    rooms = story.to_honeybee(0.01)
+    assert len(rooms) == 2
+    assert len(rooms[0]) == 6
+    assert rooms[0].volume == 300
+    assert rooms[0].floor_area == 100
+    assert rooms[0].exterior_wall_area == 90
+    assert rooms[0].exterior_aperture_area == pytest.approx(90 * 0.4, rel=1e-3)
+    assert rooms[0].average_floor_height == 3
+    assert rooms[0].check_solid(0.01, 1)
 
-    assert isinstance(hb_model.rooms[0][1].boundary_condition, Outdoors)
-    assert isinstance(hb_model.rooms[0][2].boundary_condition, Surface)
-    assert hb_model.rooms[0][2].boundary_condition.boundary_condition_object == \
-        hb_model.rooms[1][4].name
-    assert len(hb_model.rooms[0][1].apertures) == 1
-    assert len(hb_model.rooms[0][2].apertures) == 0
+    assert isinstance(rooms[0][1].boundary_condition, Outdoors)
+    assert isinstance(rooms[0][2].boundary_condition, Surface)
+    assert rooms[0][2].boundary_condition.boundary_condition_object == \
+        rooms[1][4].identifier
+    assert len(rooms[0][1].apertures) == 1
+    assert len(rooms[0][2].apertures) == 0
 
 
 def test_to_honeybee_different_heights():
     """Test the to_honeybee method with different floor and ceiling heights."""
     pts_1 = (Point3D(0, 0, 2), Point3D(10, 0, 2), Point3D(10, 10, 2), Point3D(0, 10, 2))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 5)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
-    story.solve_room_2d_adjacency(0.01)
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 5)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
     story.set_outdoor_window_parameters(SimpleWindowRatio(0.4))
+    story.solve_room_2d_adjacency(0.01)
 
-    hb_model = story.to_honeybee(True, 0.01)
-    assert isinstance(hb_model, Model)
-    assert len(hb_model.rooms) == 2
-    assert len(hb_model.rooms[0]) == 8
-    assert hb_model.rooms[0].volume == 500
-    assert hb_model.rooms[0].floor_area == 100
-    assert hb_model.rooms[0].exterior_wall_area >= 150
-    assert hb_model.rooms[0].exterior_aperture_area == pytest.approx(150 * 0.4, rel=1e-3)
-    assert hb_model.rooms[0].average_floor_height == 2
-    assert hb_model.rooms[0].check_solid(0.01, 1)
+    rooms = story.to_honeybee(True, 0.01)
+    assert len(rooms) == 2
+    assert len(rooms[0]) == 8
+    assert rooms[0].volume == 500
+    assert rooms[0].floor_area == 100
+    assert rooms[0].exterior_wall_area >= 150
+    assert rooms[0].exterior_aperture_area == pytest.approx(150 * 0.4, rel=1e-3)
+    assert rooms[0].average_floor_height == 2
+    assert rooms[0].check_solid(0.01, 1)
 
-    assert isinstance(hb_model.rooms[0][1].boundary_condition, Outdoors)
-    assert not isinstance(hb_model.rooms[0][2].boundary_condition, Surface)  # bottom
-    assert isinstance(hb_model.rooms[0][3].boundary_condition, Surface)  # middle
-    assert not isinstance(hb_model.rooms[0][4].boundary_condition, Surface)  # top
+    assert isinstance(rooms[0][1].boundary_condition, Outdoors)
+    assert not isinstance(rooms[0][2].boundary_condition, Surface)  # bottom
+    assert isinstance(rooms[0][3].boundary_condition, Surface)  # middle
+    assert not isinstance(rooms[0][4].boundary_condition, Surface)  # top
+
+    assert len(rooms[0][3].apertures) == 1
+    assert len(rooms[1][4].apertures) == 1
+    rm1_ap = rooms[0][3].apertures[0]
+    rm2_ap = rooms[1][4].apertures[0]
+    assert isinstance(rm1_ap.boundary_condition, Surface)
+    assert isinstance(rm2_ap.boundary_condition, Surface)
+    assert rm1_ap.area == pytest.approx(rm2_ap.area, rel=1e-3)
 
 
 def test_to_dict():
     """Test the Story to_dict method."""
     pts_1 = (Point3D(0, 0, 2), Point3D(10, 0, 2), Point3D(10, 10, 2), Point3D(0, 10, 2))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 5)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 5)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
     story.solve_room_2d_adjacency(0.01)
     story.set_outdoor_window_parameters(SimpleWindowRatio(0.4))
     story.set_outdoor_shading_parameters(Overhang(1))
 
     sd = story.to_dict()
     assert sd['type'] == 'Story'
-    assert sd['name'] == 'OfficeFloor'
-    assert sd['display_name'] == 'Office Floor'
+    assert sd['identifier'] == 'OfficeFloor'
+    assert sd['display_name'] == 'OfficeFloor'
     assert 'room_2ds' in sd
     assert len(sd['room_2ds']) == 2
     assert sd['floor_to_floor_height'] == 5
@@ -314,9 +320,9 @@ def test_to_from_dict():
     """Test the to/from dict of Story objects."""
     pts_1 = (Point3D(0, 0, 2), Point3D(10, 0, 2), Point3D(10, 10, 2), Point3D(0, 10, 2))
     pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
-    room2d_1 = Room2D('Office 1', Face3D(pts_1), 5)
-    room2d_2 = Room2D('Office 2', Face3D(pts_2), 3)
-    story = Story('Office Floor', [room2d_1, room2d_2])
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 5)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
     story.solve_room_2d_adjacency(0.01)
     story.set_outdoor_window_parameters(SimpleWindowRatio(0.4))
     story.set_outdoor_shading_parameters(Overhang(1))
@@ -325,3 +331,35 @@ def test_to_from_dict():
     new_story = Story.from_dict(story_dict)
     assert isinstance(new_story, Story)
     assert new_story.to_dict() == story_dict
+
+
+def test_from_dict_reversed_surface_bcs():
+    """Test the from_dict of Story objects with reversed Surface boundary conditions."""
+    pts_1 = (Point3D(0, 0, 2), Point3D(10, 0, 2), Point3D(10, 10, 2), Point3D(0, 10, 2))
+    pts_2 = (Point3D(10, 0, 3), Point3D(20, 0, 3), Point3D(20, 10, 3), Point3D(10, 10, 3))
+    room2d_1 = Room2D('Office1', Face3D(pts_1), 5)
+    room2d_2 = Room2D('Office2', Face3D(pts_2), 3)
+    story = Story('OfficeFloor', [room2d_1, room2d_2])
+    story.solve_room_2d_adjacency(0.01)
+    story_dict_original = story.to_dict()
+
+    # reverse the order of vertices in one of the rooms
+    story_dict = story.to_dict()
+    room2 = story_dict['room_2ds'][1]
+    room2['floor_boundary'] = list(reversed(room2['floor_boundary']))
+    room2['boundary_conditions'] = list(reversed(room2['boundary_conditions']))
+    room1_bc = story_dict['room_2ds'][0]['boundary_conditions'][1]
+    room1_bc['boundary_condition_objects'] = ('Office2..Face1', 'Office2')
+
+    new_story = Story.from_dict(story_dict)
+    assert new_story.to_dict() == story_dict_original
+
+    # reverse the order of vertices in both of the rooms
+    room1 = story_dict['room_2ds'][0]
+    room1['floor_boundary'] = list(reversed(room1['floor_boundary']))
+    room1['boundary_conditions'] = list(reversed(room1['boundary_conditions']))
+    room2_bc = story_dict['room_2ds'][1]['boundary_conditions'][0]
+    room2_bc['boundary_condition_objects'] = ('Office1..Face3', 'Office1')
+
+    new_story = Story.from_dict(story_dict)
+    assert new_story.to_dict() == story_dict_original
